//
//  QuestionController.m
//  Wordbook
//
//  Created by KOYAMA Yoshiaki on Fri Jul 16 2004.
//  Copyright (c) 2004 KOYAMA Yoshiaki. All rights reserved.
//

#import "QuestionController.h"
#import "Word.h"

@implementation QuestionController

#pragma mark -
#pragma mark === 問題出題処理 ====

// 開始ボタン
- (IBAction)startQuestion:(id)sender {

	[_document updateChangeCount:NSChangeDone];
//	[_window setDocumentEdited:YES];

	if ([[_radio selectedCell] tag] == 0) {
		_english = YES;
	}
	else {
		_english = NO;
	}

	_index = 0;
	_array = [_wordArrayController arrangedObjects];


	[_tabView selectTabViewItemAtIndex:1];
	[self printClear];
	[self printQuestion:_index];
}

// 解答ボタン
- (IBAction)solveQuestion:(id)sender {
	[self printAnswer:_index];

	[_solve setEnabled:NO];
	[_right setEnabled:YES];
	[_mistake setEnabled:YES];
}

// 正解ボタン
- (IBAction)rightQuestion:(id)sender {
	Word *term;
	NSNumber *number;
	int intNumber;

	term = [_array objectAtIndex:_index];	

	if (_english == YES) {
		number = [term valueForKey:@"wordRight"];
		intNumber = [number intValue];
		intNumber++;

		[term setValue:[NSNumber numberWithInt:intNumber] forKey:@"wordRight"];
	} else {
		number = [term valueForKey:@"meaningRight"];
		intNumber = [number intValue];
		intNumber++;

		[term setValue:[NSNumber numberWithInt:intNumber] forKey:@"meaningRight"];

	}

	_index++;
	if (_index < [_array count]) {
		[self printClear];
		[self printQuestion:_index];
	} else {
		[_right setEnabled:NO];
		[_mistake setEnabled:NO];
	}
}

// 不正解ボタン
- (IBAction)mistakeQuestion:(id)sender {
	Word *term;
	NSNumber *number;
	int intNumber;

	term = [_array objectAtIndex:_index];	

	if (_english == YES) {
		number = [term valueForKey:@"wordRight"];
		intNumber = [number intValue];
		intNumber--;

		[term setValue:[NSNumber numberWithInt:intNumber] forKey:@"wordRight"];
	} else {
		number = [term valueForKey:@"meaningRight"];
		intNumber = [number intValue];
		intNumber--;

		[term setValue:[NSNumber numberWithInt:intNumber] forKey:@"meaningRight"];
	}

	_index++;
	if (_index < [_array count]) {
		[self printClear];
		[self printQuestion:_index];
	} else {
		[_right setEnabled:NO];
		[_mistake setEnabled:NO];
	}

}

// 前の問題
- (IBAction)frontStepQuestion:(id)sender {
	[self printClear];
	_index--;
	if (_index < 0) {
		_index = 0;
	}
	[self printQuestion:_index];
}

// 最初の問題
- (IBAction)frontStep2Question:(id)sender {
	[self printClear];
	_index = 0;
	[self printQuestion:_index];
}

// 次の問題
- (IBAction)backStepQuestion:(id)sender {
	[self printClear];
	_index++;
	if (_index > ([_array count] - 1)) {
		_index = [_array count] - 1;
	}
	[self printQuestion:_index];
}

// 最後の問題
- (IBAction)backStep2Question:(id)sender {
	[self printClear];
	_index = [_array count] - 1;
	[self printQuestion:_index];
}

// 問題出題方法選択画面
- (IBAction)startStepQuestion:(id)sender {
	[_tabView selectTabViewItemAtIndex:0];
}

// 問題表示
- (void)printQuestion:(int)index {
	Word *term;
	NSString *word;
	NSString *symbol;
	NSString *meaning;
	NSString *wordSymbol;
	NSString *countString;
	NSString *rightString;
	NSNumber *wordRight;
	NSNumber *meaningRight;
	
	if (index >= [_array count]) {
		return;
	}

	[_solve setEnabled:YES];
	[_right setEnabled:NO];
	[_mistake setEnabled:NO];

	term = [_array objectAtIndex:_index];
	word = [term valueForKey:@"word"];
	symbol = [term valueForKey:@"symbol"];
	meaning = [term valueForKey:@"meaning"];
	wordRight = [term valueForKey:@"wordRight"];
	meaningRight = [term valueForKey:@"meaningRight"];

	if (symbol == nil) {
		symbol = @"";
	}

	countString = [NSString stringWithFormat:@"%05d/%05d", _index+1, [_array count]];
	[_count setStringValue:countString];

	if (_english == YES) {
		rightString = [NSString stringWithFormat:@"%05d", [wordRight intValue]];
		wordSymbol = [NSString stringWithFormat:@"%@\n%@", word, symbol];
		[_question setStringValue:wordSymbol];
	} else {
		rightString = [NSString stringWithFormat:@"%05d", [meaningRight intValue]];
		[_question setStringValue:meaning];
	}
		[_rightLabel setStringValue:rightString];
}

// 解答表示
- (void)printAnswer:(int)index {
	Word *term;
	NSString *word;
	NSString *symbol;
	NSString *meaning;
	NSString *wordSymbol;

	if (index >= [_array count]) {
		return;
	}

	term = [_array objectAtIndex:index];
	word = [term valueForKey:@"word"];
	symbol = [term valueForKey:@"symbol"];
	meaning = [term valueForKey:@"meaning"];

	if (symbol == nil) {
		symbol = @"";
	}

	if (_english == YES) {
		[_answer setStringValue:meaning];
	} else {
		wordSymbol = [NSString stringWithFormat:@"%@\n%@", word, symbol];
		[_answer setStringValue:wordSymbol];
	}
}

// 問題・解答を消去
- (void)printClear {
	[_question setStringValue:@""]; 
	[_answer setStringValue:@""];
}

@end
